Authors
=======

The list of contributors in alphabetical order:

- `Anton Khodak <https://orcid.org/0000-0003-3263-4553>`_
- `Dan Leehr <https://orcid.org/0000-0003-3221-9579>`_
- `Daniel Prelipcean <https://orcid.org/0000-0002-4855-194X>`_
- `Diego Rodriguez <https://orcid.org/0000-0003-0649-2002>`_
- `Dinos Kousidis <https://orcid.org/0000-0002-4914-4289>`_
- `Harri Hirvonsalo <https://orcid.org/0000-0002-5503-510X>`_
- `Jan Okraska <https://orcid.org/0000-0002-1416-3244>`_
- `Leticia Wanderley <https://orcid.org/0000-0003-4649-6630>`_
- `Lukas Heinrich <https://orcid.org/0000-0002-4048-7584>`_
- `Marco Vidal <https://orcid.org/0000-0002-9363-4971>`_
- `Michael R. Crusoe <https://orcid.org/0000-0002-2961-9670>`_
- `Robin Long <https://github.com/longr>`_
- `Rokas Maciulaitis <https://orcid.org/0000-0003-1064-6967>`_
- `Ronald Dobos <https://orcid.org/0000-0003-2914-000X>`_
- `Sasha Baranov <https://github.com/sashabaranov>`_
- `Sinclert Perez <https://www.linkedin.com/in/sinclert>`_
- `Tibor Simko <https://orcid.org/0000-0001-7202-5803>`_
